#ifndef _ELM_PLAYER_INTERNAL_PART_EO_H_
#define _ELM_PLAYER_INTERNAL_PART_EO_H_

#ifndef _ELM_PLAYER_INTERNAL_PART_EO_CLASS_TYPE
#define _ELM_PLAYER_INTERNAL_PART_EO_CLASS_TYPE

typedef Eo Elm_Player_Internal_Part;

#endif

#ifndef _ELM_PLAYER_INTERNAL_PART_EO_TYPES
#define _ELM_PLAYER_INTERNAL_PART_EO_TYPES


#endif
/** Elementary player internal part class
 *
 * @ingroup Elm_Player_Internal_Part
 */
#define ELM_PLAYER_INTERNAL_PART_CLASS elm_player_internal_part_class_get()

EWAPI const Efl_Class *elm_player_internal_part_class_get(void);

#endif
